# AnomalyDetectionModel
AnomalyDetectionModels

[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

## Overview

`AnomalyDetectionModel` is a python library that includs some simple implementation of an anomaly detection model.   
For more details, please refer to the document page:   
[Document](https://read-doc-1.readthedocs.io/en/main/index.html)   
pypi page link is here:(https://pypi.org/project/df-csv-excel/)   

### Quick Start
#### Installation

You can install `AnomalyDetectionModel` using pip:

```
pip install AnomalyDetectionModel
```